@@ -54,7 +54,7 @@ class Assistant(GenericAssistant):
                 print("To calibrate your voice, please speak the following after the beep: 'A quick brown fox jumped "
                       "over the lazy dog'")
                 time.sleep(2)
-                playsound('audio_samples/audio_sample_4.wav')
+                playsound('./audio_samples/audio_sample_4.wav')
                 self.recognizer.adjust_for_ambient_noise(source, duration=1)
                 audio = self.recognizer.listen(source)
 
@@ -73,7 +73,7 @@ class Assistant(GenericAssistant):
                 print(f"Could not request results from Speech Recognition service; {e}")
 
     def listen(self):
-        playsound("audio_samples/audio_sample_4.wav")
+        playsound("./audio_samples/audio_sample_4.wav")
         with self.microphone as source:
             try:
                 while True:
@@ -140,7 +140,7 @@ class Assistant(GenericAssistant):
         self.tasks.task_done()
 
     def assist(self):
-        # self.calibrate()
+        self.calibrate()
         self.listen()
 
     def set_name(self):
